vfbLib.parsers.guides.GlobalGuidesParser
========================================

.. currentmodule:: vfbLib.parsers.guides

.. autoclass:: GlobalGuidesParser
   :members:
   :show-inheritance:
   :inherited-members:

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~GlobalGuidesParser.__init__
      ~GlobalGuidesParser.parse
      ~GlobalGuidesParser.parse_hex
      ~GlobalGuidesParser.read_double
      ~GlobalGuidesParser.read_doubles
      ~GlobalGuidesParser.read_float
      ~GlobalGuidesParser.read_floats
      ~GlobalGuidesParser.read_int16
      ~GlobalGuidesParser.read_int32
      ~GlobalGuidesParser.read_int8
      ~GlobalGuidesParser.read_str
      ~GlobalGuidesParser.read_str_all
      ~GlobalGuidesParser.read_uint16
      ~GlobalGuidesParser.read_uint32
      ~GlobalGuidesParser.read_uint8
      ~GlobalGuidesParser.read_value
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~GlobalGuidesParser.encoding
      ~GlobalGuidesParser.master_count
      ~GlobalGuidesParser.stream
      ~GlobalGuidesParser.ttStemsH_count
      ~GlobalGuidesParser.ttStemsV_count
   
   